==> 0.0.1.tar.gz: main.dart <==
import 'dart:ffi';
import 'dart:typed_data';

import 'XData.dart';
import 'XDataWriter.dart';
import 'XDataParser.dart';
import 'TTUser.dart';
import "TXTestRequest.dart";
import "TXAllTypeModel.dart";
import 'XDataWrapper.dart';
import 'XBaseRecordWrapper.dart';
import 'XBaseRecord.dart';

import 'TXAllTypeModelWrapper.dart';
import 'TXTestRequestWrapper.dart';

main() {
  //testUser();
  //testALlType();
  //testWrapper();
  testXDataWrapper();
  //testXDataWrapper2();
}

testWrapper() {
  XBaseRecordWrapper wrapper = XBaseRecordWrapper();
  wrapper.VERSION = 10000;
  wrapper.STATUS = 100;
  wrapper.ID = 102032;
  wrapper.ADD_VERSION = 24034;

  printBaseRecord(wrapper);

  XDataWriter writer = XDataWriter();
  Int8List bytes = writer.write(wrapper);

  XDataParser parser = XDataParser();
  XData out = parser.parse(bytes);
  XBaseRecordWrapper outWrapper = XBaseRecordWrapper.withData(out);
  printBaseRecord(outWrapper);

}

printBaseRecord(XBaseRecordWrapper wraper) {
  print(wraper.ID);
  print(wraper.STATUS);
  print(wraper.ADD_VERSION);
  print(wraper.ADD_VERSION);

}

testUser() {
  XData data = new XData(TTUser.TYPE_INDEX);
  data.set(TTUser.mobile, "18017701717");
  data.set(TTUser.name, "赵");
  data.set(TTUser.password, "123456");

  XDataWriter writer = XDataWriter();
  Int8List bytes = writer.write(data);
  print(bytes);

  printUser(data);

  XDataParser parser = XDataParser();

  XData out = parser.parse(bytes);
  printUser(out);
}

testALlType() {
  XData request = createRequest();
  XDataWriter writer = XDataWriter();
  Int8List bytes = writer.write(request);
  print(bytes);
  XDataParser parser = XDataParser();
  XData out = parser.parse(bytes);
  printRequest(out);
}

printUser(XData data) {
  var name = data.get(TTUser.name);
  print("name is $name");

  var mobile = data.get(TTUser.mobile);
  print("name is $mobile");

  var password = data.get(TTUser.password);
  print("name is $password");
}

XData createRequest() {
  XData request = new XData(TXTestRequest.TYPE_INDEX);
  request.set(TXTestRequest.id, 123343454358954328);
  List datas = List();
  for (var i =0;i<3;i++) {
     XData model = XData(TXAllTypeModel.TYPE_INDEX);
     model.set(TXAllTypeModel.name, "上海市");
     model.set(TXAllTypeModel.age, 127);
     model.set(TXAllTypeModel.createTime, DateTime.now().millisecondsSinceEpoch);
     model.set(TXAllTypeModel.followCount, 98765);
     model.set(TXAllTypeModel.money, 18423.51);
     model.set(TXAllTypeModel.price, 898874545.05870972);
     model.set(TXAllTypeModel.friendCount, 8798776);
     datas.add(model);
  }
  request.set(TXTestRequest.datas, datas);
  return request;
}

printRequest(XData request) {
  print("request.id ${request.get(TXTestRequest.id)}");
  List datas = request.get(TXTestRequest.datas) as List;
  print("request.data length: ${datas?.length}");
  datas?.forEach((data){
    printModel(data);
  });
}

printRequestWrapper(TXTestRequestWrapper request) {
  print("request.id ${request.id}");
  print("request.data length: ${request.datas.length}");
  request.datas?.forEach((data){
    printModel(data);
  });
}

printModel(XData model) {
  print("name ${model.get(TXAllTypeModel.name)}");
  print("age ${model.get(TXAllTypeModel.age)}");
  print("friendCount ${model.get(TXAllTypeModel.friendCount)}");
  print("followCount ${model.get(TXAllTypeModel.followCount)}");
  print("price ${model.get(TXAllTypeModel.price)}");
  print("money ${(model.get(TXAllTypeModel.money) as double).toStringAsFixed(7)}");
  print("createTime ${model.get(TXAllTypeModel.createTime)}");
}

printModelWrapper(TXAllTypeModelWrapper model) {
  print("name ${model.name}");
  print("age ${model.age}");
  print("friendCount ${model.friendCount}");
  print("followCount ${model.followCount}");
  print("price ${model.price}");
  print("money ${model.money}");
  print("createTime ${model.createTime}");
}

testXDataWrapper() {
  TXTestRequestWrapper wrapper = TXTestRequestWrapper();
  wrapper.id = 123032;
  List datas = List<TXAllTypeModelWrapper>();
  for(int i=0;i<2;i++) {
    TXAllTypeModelWrapper model = TXAllTypeModelWrapper();
    model.price = 1000.05;
    model.name = "OPhone";
    model.createTime = DateTime.now().millisecondsSinceEpoch;
    model.money = 12334.98;
    model.followCount = 123;
    model.friendCount = 3353;
    model.age = 55;
    datas.add(model);
  }
  wrapper.datas = datas;

  XDataWriter writer = XDataWriter();
  var bytes = writer.write(wrapper);
  XDataParser parser = XDataParser();
  var out = parser.parse(bytes);
  var outWrapper = TXTestRequestWrapper.withData(out);

  printRequest(outWrapper);
}

testXDataWrapper2() {
  XData wrapper = XData(TXTestRequest.TYPE_INDEX);
  wrapper.set(TXTestRequest.id,  123032);
  List datas = List<XData>();
  for(int i=0;i<2;i++) {
    XData model = XData(TXAllTypeModel.TYPE_INDEX);
    model.set(TXAllTypeModel.price, 1000.05);
    model.set(TXAllTypeModel.name, "OPhone");
    model.set(TXAllTypeModel.createTime, DateTime.now().millisecondsSinceEpoch);
    model.set(TXAllTypeModel.followCount, 123);
    model.set(TXAllTypeModel.friendCount, 3353);
    model.set(TXAllTypeModel.money,12334.98);
    model.set(TXAllTypeModel.age,55);
    datas.add(model);
  }
  wrapper.set(TXTestRequest.datas, datas);

  XDataWriter writer = XDataWriter();
  var bytes = writer.write(wrapper);
  XDataParser parser = XDataParser();
  var out = parser.parse(bytes);
  var outWrapper = TXTestRequestWrapper.withData(out);

  printRequestWrapper(outWrapper);
}

==> 0.0.2.tar.gz: main.dart <==
import 'dart:ffi';
import 'dart:typed_data';

import 'package:xdata/XData.dart';
import 'package:xdata/XDataWriter.dart';
import 'package:xdata/XDataParser.dart';
import 'TTUser.dart';
import "TXTestRequest.dart";
import "TXAllTypeModel.dart";
import 'package:xdata/XDataWrapper.dart';
import 'package:xdata/XBaseRecordWrapper.dart';
import 'package:xdata/XBaseRecord.dart';

import 'TXAllTypeModelWrapper.dart';
import 'TXTestRequestWrapper.dart';

main() {
  //testUser();
  //testALlType();
  //testWrapper();
  testXDataWrapper();
  //testXDataWrapper2();
}

testWrapper() {
  XBaseRecordWrapper wrapper = XBaseRecordWrapper();
  wrapper.VERSION = 10000;
  wrapper.STATUS = 100;
  wrapper.ID = 102032;
  wrapper.ADD_VERSION = 24034;

  printBaseRecord(wrapper);

  XDataWriter writer = XDataWriter();
  Int8List bytes = writer.write(wrapper);

  XDataParser parser = XDataParser();
  XData out = parser.parse(bytes);
  XBaseRecordWrapper outWrapper = XBaseRecordWrapper.withData(out);
  printBaseRecord(outWrapper);

}

printBaseRecord(XBaseRecordWrapper wraper) {
  print(wraper.ID);
  print(wraper.STATUS);
  print(wraper.ADD_VERSION);
  print(wraper.ADD_VERSION);

}

testUser() {
  XData data = new XData(TTUser.TYPE_INDEX);
  data.set(TTUser.mobile, "18017701717");
  data.set(TTUser.name, "赵");
  data.set(TTUser.password, "123456");

  XDataWriter writer = XDataWriter();
  Int8List bytes = writer.write(data);
  print(bytes);

  printUser(data);

  XDataParser parser = XDataParser();

  XData out = parser.parse(bytes);
  printUser(out);
}

testALlType() {
  XData request = createRequest();
  XDataWriter writer = XDataWriter();
  Int8List bytes = writer.write(request);
  print(bytes);
  XDataParser parser = XDataParser();
  XData out = parser.parse(bytes);
  printRequest(out);
}

printUser(XData data) {
  var name = data.get(TTUser.name);
  print("name is $name");

  var mobile = data.get(TTUser.mobile);
  print("name is $mobile");

  var password = data.get(TTUser.password);
  print("name is $password");
}

XData createRequest() {
  XData request = new XData(TXTestRequest.TYPE_INDEX);
  request.set(TXTestRequest.id, 123343454358954328);
  List datas = List();
  for (var i =0;i<3;i++) {
     XData model = XData(TXAllTypeModel.TYPE_INDEX);
     model.set(TXAllTypeModel.name, "上海市");
     model.set(TXAllTypeModel.age, 127);
     model.set(TXAllTypeModel.createTime, DateTime.now().millisecondsSinceEpoch);
     model.set(TXAllTypeModel.followCount, 98765);
     model.set(TXAllTypeModel.money, 18423.51);
     model.set(TXAllTypeModel.price, 898874545.05870972);
     model.set(TXAllTypeModel.friendCount, 8798776);
     datas.add(model);
  }
  request.set(TXTestRequest.datas, datas);
  return request;
}

printRequest(XData request) {
  print("request.id ${request.get(TXTestRequest.id)}");
  List datas = request.get(TXTestRequest.datas) as List;
  print("request.data length: ${datas?.length}");
  datas?.forEach((data){
    printModel(data);
  });
}

printRequestWrapper(TXTestRequestWrapper request) {
  print("request.id ${request.id}");
  print("request.data length: ${request.datas.length}");
  request.datas?.forEach((data){
    printModel(data);
  });
}

printModel(XData model) {
  print("name ${model.get(TXAllTypeModel.name)}");
  print("age ${model.get(TXAllTypeModel.age)}");
  print("friendCount ${model.get(TXAllTypeModel.friendCount)}");
  print("followCount ${model.get(TXAllTypeModel.followCount)}");
  print("price ${model.get(TXAllTypeModel.price)}");
  print("money ${(model.get(TXAllTypeModel.money) as double).toStringAsFixed(7)}");
  print("createTime ${model.get(TXAllTypeModel.createTime)}");
}

printModelWrapper(TXAllTypeModelWrapper model) {
  print("name ${model.name}");
  print("age ${model.age}");
  print("friendCount ${model.friendCount}");
  print("followCount ${model.followCount}");
  print("price ${model.price}");
  print("money ${model.money}");
  print("createTime ${model.createTime}");
}

testXDataWrapper() {
  TXTestRequestWrapper wrapper = TXTestRequestWrapper();
  wrapper.id = 123032;
  List datas = List<TXAllTypeModelWrapper>();
  for(int i=0;i<2;i++) {
    TXAllTypeModelWrapper model = TXAllTypeModelWrapper();
    model.price = 1000.05;
    model.name = "OPhone";
    model.createTime = DateTime.now().millisecondsSinceEpoch;
    model.money = 12334.98;
    model.followCount = 123;
    model.friendCount = 3353;
    model.age = 55;
    datas.add(model);
  }
  wrapper.datas = datas;

  XDataWriter writer = XDataWriter();
  var bytes = writer.write(wrapper);
  XDataParser parser = XDataParser();
  var out = parser.parse(bytes);
  var outWrapper = TXTestRequestWrapper.withData(out);

  printRequest(outWrapper);
}

testXDataWrapper2() {
  XData wrapper = XData(TXTestRequest.TYPE_INDEX);
  wrapper.set(TXTestRequest.id,  123032);
  List datas = List<XData>();
  for(int i=0;i<2;i++) {
    XData model = XData(TXAllTypeModel.TYPE_INDEX);
    model.set(TXAllTypeModel.price, 1000.05);
    model.set(TXAllTypeModel.name, "OPhone");
    model.set(TXAllTypeModel.createTime, DateTime.now().millisecondsSinceEpoch);
    model.set(TXAllTypeModel.followCount, 123);
    model.set(TXAllTypeModel.friendCount, 3353);
    model.set(TXAllTypeModel.money,12334.98);
    model.set(TXAllTypeModel.age,55);
    datas.add(model);
  }
  wrapper.set(TXTestRequest.datas, datas);

  XDataWriter writer = XDataWriter();
  var bytes = writer.write(wrapper);
  XDataParser parser = XDataParser();
  var out = parser.parse(bytes);
  var outWrapper = TXTestRequestWrapper.withData(out);

  printRequestWrapper(outWrapper);
}
